OC.L10N.register(
    "bookmarks",
    {
    "Rename" : "නැවත නම් කරන්න",
    "Move" : "Move",
    "Delete" : "ඉවත් කරන්න",
    "Search" : "Search",
    "New" : "නව",
    "Cancel" : "අවලංගු කරන්න",
    "Import" : "ආයාත කරන්න",
    "Export" : "නිර්යාත කරන්න",
    "Title" : "මාතෘකාව",
    "Link" : "Link",
    "Tags" : "ටැග",
    "Notes" : "සටහන්",
    "Owner" : "Owner",
    "Sharing" : "හුවමාරු කිරීම",
    "Share link" : "Share link",
    "Select" : "Select",
    "Folder" : "ෆෝල්ඩරය",
    "Save" : "සුරකින්න"
},
"nplurals=2; plural=(n != 1);");
